;+
; stray.pro
; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
; Determines stray light for radius r (Rsun units).
; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
; Andrew L. Stanger
; SMM C/P   HAO/NCAR
; 1 March 1984
; 10 December 1985: Apply Munro calibration correction.
; 19 June 1990: Apply Munro correction factor ONLY if lcc = 1.
; 17 June 1998: Conversion from C to IDL.  Use cc = 2.0 (Jupiter correction).
; * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
;-

FUNCTION stray, r

;---r:	/* Radius (Rsun). */

Cexp = 1.0e-11		;/* Scale factor for strtab table. */
cc   = 2.0		;/* Jupiter calibration correction value. */
; s			;/* Stray light value. */

;/* Radial values in units of R/Rsun corresponding to stray light table. */

rtab = 								   $
     [ 0.00, 0.10, 0.20, 0.30, 0.40, 0.50, 0.60, 0.70, 0.80, 0.90, $
       1.00, 1.10, 1.20, 1.30, 1.40, 1.50, 1.60, 1.70, 1.80, 1.90, $
       2.00, 2.10, 2.20, 2.30, 2.40, 2.50, 2.60, 2.70, 2.80, 2.90, $
       3.00, 3.10, 3.20, 3.30, 3.40, 3.50, 3.60, 3.70, 3.80, 3.90, $
       4.00, 4.10, 4.20, 4.30, 4.40, 4.50, 4.60, 4.70, 4.80, 4.90, $
       5.00, 5.10, 5.20, 5.30, 5.40, 5.50, 5.60, 5.70, 5.80, 5.90, $
       6.00, 6.10, 6.20, 6.30, 6.40, 6.50, 6.60, 6.70, 6.80, 6.90, $
       7.00, 7.10, 7.20, 7.30, 7.40, 7.50, 7.60, 7.70, 7.80, 7.90, $
       8.00, 8.10, 8.20, 8.30, 8.40, 8.50, 8.60]

; Stray light values in radiance units (10**-11 B/Bsun)
; in increments of 0.1 solar radius, beginning with 0.0 Rsun and
; continuing out to 8.4 Rsun.
;
; stray light estimate : William Wagner 24 July 1982 graph (smstr2).
;

strtab =							 	    $
     [ 0.00,  0.00,  0.00,  0.00,  0.00,  0.00,  0.00,  0.00,  0.00,  0.00, $
      -1.00,  0.00,  0.00,  0.00,  0.00, 90.00, 190.0, 110.0, 67.00, 45.00, $
      36.00, 29.00, 25.50, 23.00, 21.50, 20.50, 20.20, 20.10, 20.03, 20.00, $
      20.03, 20.10, 20.20, 20.50, 21.00, 23.00, 28.50, 29.50, 29.80, 29.90, $
      30.00, 30.05, 30.00, 30.00, 29.00, 27.50, 25.50, 23.50, 21.50, 20.70, $
      20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00, $
      20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00, $
      20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00, $
      20.00, 20.00, 20.00, 20.00, 20.00, 20.00, 20.00]

;* ------------------------------------------------------------------------- */
   size_strtab = size (strtab)
   NTAB = size_strtab (1)

   s = lint (r, rtab, strtab, NTAB) * Cexp * cc

   RETURN, s

END
